#b File tres/Scripts/trsfib0.cl
# By Doug Mink
# October 5, 2007

# TRSFIB0 -- Figure out and optionally set FIB1, FIB2, and FIB3 keywords
#            in a TRES data file using the values of other keywords
#	     *** replaced by t_trsfib.x ***

procedure trsfib0 (spectrum)

file spectrum=""	{prompt="File to process"}

string specdir=""	{prompt="Input directory for data files"}
bool addfib=yes		{prompt="Add FIBi keywords to spectra (yes or no)"}
string imtype=""	{prompt="IRAF image type"}
string object=""	{prompt="Object name"}
string peri="IN"	{prompt="Periscope IN (Fibers 1 and 2) or OUT (fiber 3)"}
string bin1="1"		{prompt="Binning (1 or 2)"}
string fibsize="1.4"	{prompt="Fiber size (1.3 2.3 2.8)"}
string osswitch="NO"	{prompt="NO: 1=object 2=sky  YES: 1=sky 2=object"}
string exptime=""	{prompt="Exposure time in seconds"}
string comptime="0.0"	{prompt="Comparison lamp flash (peri=OUT) time in sec"}
string fib1="OFF"	{prompt="Fiber 1 (usually object) content (returned)"}
string fib2="OFF"	{prompt="Fiber 2 (usually sky) content (returned)"}
string fib3="OFF"	{prompt="Fiber 3 (usually comp) content (returned)"}
string binning=""	{prompt="TRES binning (b if 2, null if 1) (returned)"}
string apsize="s"	{prompt="TRES aperture size (s=1.8, m=2.3, l=2.9) (returned)"}
bool verbose=yes	{prompt="Log progress (yes or no)"}
bool debug=no		{prompt="Print debugging information (yes or no)"}

begin
	bool vb, db, fibinhead
	file imf
	file indir
	string args, bin2, ccdsum
	string filename
	real ctime, etime

	vb = verbose
	db = debug
	fixdir (specdir)
	indir = fixdir.newdir
	if (indir == "")
	    imf = spectrum
	else
	    imf = indir // spectrum

	if (!deftask ("gethead")) {
	    wcstools (motd=no)
	    }

# Print column headings for verbose mode
	if (debug) {
	    print ("filename          type    object  peri    bin     fibsize osswitch        exptime comptime        fib1    fib2    fib3")
	    print ("-----------       ------- ------  ----    ---     ------- --------        ------- --------        ----    ----    ----")
	    }

# Read important keyword values fo this file
	args = imf // " -abun 1 imagetyp object peri ccdsum fibsize osswitch exptime comptime fib1 fib2 fib3"
	gethead (args) | scan (filename, imtype, object, peri, ccdsum, fibsize, osswitch, exptime, comptime, fib1, fib2, fib3)
	if (db) {
	    gethead (args)
	    print ("TRESFIB: filename= ",filename, " object= ",object)
	    print ("TRESFIB: peri ",peri," ccdsum= ", ccdsum)
	    print ("TRESFIB: fibsize= ",fibsize," osswitch= ",osswitch)
	    print ("TRESFIB: exptime= ",exptime," comptime= ",comptime)
	    }

# Set FIBi values if not in header already
	fibinhead = yes
	if (fib1 == "___" || fib2 == "___" || fib3 == "___") {
	    fibinhead = no
	    ctime = real (comptime)
	    etime = real (exptime)
	    if (imtype == "FLAT") {
		if (peri == "IN") {
		    fib1 = "FLAT"
		    fib2 = "FLAT"
		    fib3 = "OFF"
		    }
		else {
		    fib1 = "OFF"
		    fib2 = "OFF"
		    fib3 = "FLAT"
		    }
		}
	    else if (imtype == "OBJECT") {
		if (object == "COMP") {
		    if (peri == "IN") {
			fib1 = "COMP"
			fib2 = "COMP"
			fib3 = "OFF"
			}
		    else {
			fib1 = "OFF"
			fib2 = "OFF"
			fib3 = "COMP"
			}
		    }
		else if (ctime > 0.0) {
		    if (peri == "OUT") {
			if (osswitch == "YES") {
			    fib1 = "SKY"
			    fib2 = "OBJ"
			    fib3 = "COMP"
			    }
			else {
			    fib1 = "OBJ"
			    fib2 = "SKY"
			    fib3 = "COMP"
			    }
			}
		    else {
			fib1 = "OFF"
			fib2 = "OFF"
			fib3 = "OFF"
			}
		    }
		else {
		    if (peri == "OUT") {
			if (osswitch == "YES") {
			    fib1 = "SKY"
			    fib2 = "OBJ"
			    fib3 = "OFF"
			    }
			else {
			    fib1 = "OBJ"
			    fib2 = "SKY"
			    fib3 = "OFF"
			    }
			}
		    else {
			fib1 = "OFF"
			fib2 = "OFF"
			fib3 = "OFF"
			}
		    }
		}
	    else if (imtype == "DARK") {
		fib1 = "OFF"
		fib2 = "OFF"
		fib3 = "OFF"
		}
	    else if (imtype == "ZERO") {
		fib1 = "OFF"
		fib2 = "OFF"
		fib3 = "OFF"
		}
	    }

	bin1 = substr (ccdsum, 1, 1)
	if (bin1 == "2")
	    binning = "b"
	else
	    binning = ""
	if (fibsize == "1.8")
	    apsize = "s"
	else if (fibsize == "2.3")
	    apsize = "m"
	else
	    apsize = "l"

# Add FIBi keywords to input file if requested
	if (addfib && !fibinhead) {
	    hedit (imf, "FIB1", fib1, update+, verify-, add+)
	    hedit (imf, "FIB2", fib2, update+, verify-, add+)
	    hedit (imf, "FIB3", fib3, update+, verify-, add+)
	    }

	if (vb)
	    printf ("%s	%s	%s	%s	%s	%s	%s	%s	%s	%s	%s	%s\n", filename, imtype, object, peri, bin1, fibsize, osswitch, exptime, comptime, fib1, fib2, fib3)

end
# Oct  3 2007	New program
# Oct  5 2007	Fix FIBi writing; replace input spaces in strings with _

# Jan 10 2008	Rename tresfib.cl to trsfib0.cl (replaced by SPP t_trsfib.x)
