# File tres/Scripts/tcxcsao.cl
# April 9, 2008
# By Doug Mink, SAO Telescope Data Center

# TCXCSAO - Run pxcsao on a calibration image

procedure tcxcsao (images)

string  images=""       {prompt="Images to process"}

string	template=""	{prompt="Template (null is reference template)"}
string	tempdir=""	{prompt="Template directory if template specified"}
file	logfile=""	{prompt="File for per-spectrum velocity results"}
bool	curmode=no	{prompt="Stop after each order (yes or no)"}

struct *calfiles

begin
    file imin, templist, imout, xlog

    string ims

    ims = images
    if (logfile == "") {
	xlog = "tcxcsao.log"
	}
    else {
	xlog = logfile
	}

    if (!deftask ("pxcsao")) {
	rvsao (motd=no)
	}

    pxcsao.specnum = "1-51"
    pxcsao.specband = 0
    pxcsao.specdir = ""
    pxcsao.correlate = "pixel"
    pxcsao.tempnum = "1-51"
    pxcsao.tempband = 1
    pxcsao.echelle = yes
    pxcsao.st_lambda = INDEF
    pxcsao.end_lambda = INDEF
    pxcsao.obj_plot = no
    pxcsao.xcor_plot = no
    pxcsao.xcor_file = no
    pxcsao.fixbad = no
    pxcsao.badlines = "tharskip.dat"
    pxcsao.s_emchop = "no"
    pxcsao.t_emchop = "no"
    pxcsao.s_abs_reject = 100.
    pxcsao.s_em_reject = 2.
    pxcsao.t_abs_reject = 0.
    pxcsao.t_em_reject = 0.
    pxcsao.bell_window = 0.05
    pxcsao.renormalize = no
    pxcsao.ncols = 65536
    pxcsao.interp_mode = "sums"
    pxcsao.zeropad = "yes"
    pxcsao.low_bin = 5
    pxcsao.top_low = 20
    pxcsao.top_nrun = 65536
    pxcsao.nrun = 65536
    pxcsao.vel_init = "zero"
    pxcsao.czguess = 0.
    pxcsao.nzpass = 0
    pxcsao.tshift = 0.
    pxcsao.svel_corr = "none"
    pxcsao.tvel_corr = "none"
    pxcsao.pkmode = 3
    pxcsao.pkfrac = 0.95
    pxcsao.pksrch = 25
    pxcsao.minvel = -50.
    pxcsao.maxvel = 50.
    pxcsao.report_mode = 18
    pxcsao.logfiles = "STDOUT,xcsao.log"
    pxcsao.save_vel = no
    pxcsao.rvcheck = no
    pxcsao.archive = no
    pxcsao.nsmooth = 0
    pxcsao.cvel = INDEF
    pxcsao.dvel = INDEF
    pxcsao.ablines = ""
    pxcsao.emlines = "thar.dat"
    pxcsao.linedir = "tres$lib/"
    pxcsao.dispmode = 1
    pxcsao.displot = no
    pxcsao.device = "stdgraph"
    pxcsao.vel_plot = "correlation"
    pxcsao.curmode = no
    pxcsao.hardcopy = no
    pxcsao.plotter = "stdplot"
    pxcsao.besttemp = ""
    pxcsao.velocity = 0.0
    pxcsao.velerr = 0.00
    pxcsao.r = 0.0
    pxcsao.temp_plot = no
    pxcsao.contsub_plot = no
    pxcsao.apodize_plot = no
    pxcsao.fft_plot = no
    pxcsao.tfft_plot = no
    pxcsao.uxcor_plot = no
    pxcsao.nsum = 1
    pxcsao.debug = no
    pxcsao.cursor = ""

#  Make temporary list of input files
    templist = mktemp ("tempcomp") // ".list"
    files (ims, >templist)

    calfiles = templist
    while (fscan (calfiles, imin) != EOF) {

	if (template == "") {
	    tidref (imin)
	    pxcsao.templates = tidref.reffile
	    pxcsao.tempdir = tidref.refdir
	    }
	else {
	    pxcsao.templates = template
	    pxcsao.tempdir = tempdir
	    }
	pxcsao (imin)
	print ("TCXCSAO: ",imin,", vel=",pxcsao.velocity," +-",pxcsao.velerr)
	print (imin," ",pxcsao.velocity," ",pxcsao.velerr, >> xlog)
	}

    calfiles = ""
    delete (templist)
end
# Mar 20 2008	New task
# Apr  4 2008	Write out individual file results to new parameter logfile or tcxcsao.log
# Apr  9 2008	Add template parameter to allow one to be specified
