# File tres/Scripts/tdisp1.cl
# March 18, 2008
# By Doug Mink

#  TDISP1 -- Dispersion correct a TRES spectrum

procedure tdisp1 (spectrum)

string	spectrum=""	{prompt="Image to correct"}

string	refroot="comp"	{prompt="Root name for reference comparison file"}
string	refdir="tresdata$" {prompt="Directory for reference comparison file"}
real	shift=0.0	{prompt="Pixel shift of reference comparison file"}
bool	saveold = yes	{prompt="Save original file to Nodisp/ (y or n)"}
bool	verbose=yes	{prompt="Print process progress (y or n)"}
bool	debug=no	{prompt="Print extra information (y or n)"}

begin

    string imin, calref, croot, cdir, tsize, tbin, fiber, history
    file imref, impix, rdir, newfile, calpath
    bool vb, db
    real shft
    rdir = refdir

    imin = spectrum
    shft = shift
    vb = verbose
    db = debug

# Skip this file if it has already been dispersion-corrected
    imgetp.default = "0"
    imgetp (imin, "TDISP")
    if (imgetp.value != "0") {
	if (vb) {
	    print ("TDISP1: ", imin, " has been dispersion-corrected")
	    print ("TDISP = ", imgetp.value)
	    }
	return
	}

# Find wavelength calibration file for this spectrum
    if (refroot != "") {
	tdispref (imin, refroot=refroot, refdir=rdir, verbose=vb, debug=db)
	imref = tdispref.reffile

# Copy reference database/id file with shift from correlation
	tmodid.indir = rdir
	tmodid.outdir = ""
	tmodid.shift = shft
	if (shft != 0.0) {
	    hedit (imin, "TIDSHIFT", shft, add+, update+,verify-)
	    tmodid.keepfit = no
	    }
	else
	    tmodid.keepfit = yes
	tmodid.scale = 1.0
	tmodid.verbose = vb
	tmodid.debug = db
	tmodid (imref, imin)
	}

# If id file for this file does not exist, exit
    fileroot (imin)
    calref = fileroot.rootname
    calpath = "database/ec" // calref
    if (!access (calpath)) {
	print ("TDISP1: ", calpath, " does not exist")
	return
	}

    if (shift != 0.0) {
	hedit (imin, "TIDSHIFT", (shift), add+, update+,verify-)
	}

# Use local copy of shifted reference spectrum for dispersion
    hedit (imin, "REFSPEC1", calref, add+, update+,verify-)

# Set dispersion task parameters
    dispcor.linearize = no
    dispcor.database = "database"
    dispcor.table = ""
    dispcor.w1 = INDEF
    dispcor.w2 = INDEF
    dispcor.dw = INDEF
    dispcor.nw = INDEF
    dispcor.log = no
    dispcor.flux = yes
    dispcor.blank = 0.
    dispcor.samedisp = no
    dispcor.global = no
    dispcor.ignoreaps = no
    dispcor.confirm = no
    dispcor.listonly = no
    dispcor.verbose = vb
    dispcor.logfile = ""

# Add dispersion function to spectrum file header
    fileroot (calref)
    impix = fileroot.rootname // "p.ec.fits"
    rename (imin, impix)
    dispcor (impix, imin, linearize=no)

# Add history line including time
    gettime ()
    history = gettime.date // " " // gettime.time
    history = history // " dispersion fit from " // tdispref.refpath
    hedit (imin, "TDISP", history, add+, verify-)

# Move original file to Nodisp directory
    if (saveold) {
	if (!access ("Nodisp/")) {
	    mkdir ("Nodisp")
	    if (vb)
		print ("TCAL: Making directory Nodisp/")
	    }
	newfile = "Nodisp/" // imin
	if (access (newfile)) {
	    imdelete (newfile)
	    }
	rename (impix, newfile)
	if (vb) {
	    print ("TDISP1: Original ", imin, " => Nodisp/")
	    }
	}

end

# Jan 28 2008	New task
# Jan 29 2008	Add saveold to save undispersed spectrum to Nodisp/
# Jan 29 2008	Write TCAL FITS parameter to output file
# Jan 30 2008	Note that directory is being created if verbose
# Feb 13 2008	Return immediately if file is already dispersion-corrected
# Feb 25 2008	Rename from TDISP to TDISP1 since it only operates on one file
# Mar 11 2008	Exit if no reference root is specified and id file is missing
# Mar 11 2008	If shift is not zero, write it to header as TIDSHIFT
# Mar 18 2008	Add missing quotation mark
