# File tres/Scripts/trsfiles.cl
# By Doug Mink
# April 10, 2008

# TRSFILES -- Make list file of images given a range of sequence numbers
#             or a list of file names

procedure trsfiles (images)

string images="1-300"	{prompt="Files to process"}

string datedir=""	{prompt="Date for images"}
string instdir=""	{prompt="Directory containing date directories"}
bool adddate=no		{prompt="Prepend observation date to file name (yes or no)"}
file tempin=""		{prompt="List file made from images (returned)"}
file tempout=""		{prompt="List file of real image names (returned)"}
int maxlfile=0		{prompt="Maximum length of file names (returned)"}
int maxlobj=0		{prompt="Maximum length of object names (returned)"}
bool copyfile=no	{prompt="Copy files to current directory (yes or no)"}
bool verbose=yes	{prompt="Print table of image parameters (yes or no)"}
bool debug=no		{prompt="Print table with more image parameters (yes or no)"}

begin
    bool vb, db, cp, ad
    file idir, imdir
    file impath, imin, imfile
    string ims, ddir
    int n, nrange, lfile, lobj
    string specs, olist, lastpath, obj

    vb = verbose
    db = debug
    cp = copyfile
    ad = adddate
    ims = images
    idir = instdir
    ddir = datedir

#  Make temporary list of input files
    tempin = mktemp ("tempin") // ".list"
    if (access (tempin))
	delete (tempin)
    isrange (ims)
    if (isrange.range) {
	getrange (ims, 0)
	nrange = getrange.nval
	for (i = 1; i <= nrange; i = i + 1) {
	    getrange (ims, i)
	    if (i == 1)
		print (getrange.ival, > tempin)
	    else
		print (getrange.ival, >> tempin)
	    }
	}
    else
	files (ims, >tempin)
    tempout = mktemp ("tempout") // ".list"
    if (access (tempout))
	delete (tempout)
    maxlfile = 0
    maxlobj = 0

# Make list of image paths if instrument directory is specified
    if (idir != "" || isrange.range) {
	fixdir (idir)
	imdir = fixdir.newdir
	if (ddir != "") {
	    imdir = imdir // ddir
	    fixdir (imdir)
	    imdir = fixdir.newdir
	}
	if (!access (imdir)) {
	    print ("TRSFILES cannot read directory ",imdir)
	    return
	    }
	lastpath = ""

	list = tempin
	while (fscan (list,imin) != EOF) {

# If a number is given, prepend appropriate zeroes and wildcard
	    isnum (imin)
	    if (isnum.fpcode > 0) {
		n = int (imin)
		if (n < 10)
		    imin = "000" // n // ".*"
		else if (n < 100)
		    imin = "00" // n // ".*"
		else if (n < 1000)
		    imin = "0" // n // ".*"
		else
		    imin = n // ".*"
		}

# If file extension is missing, add wildcard
	    else {
		smatch (imin, ".fits")
		if (smatch.found == no)
		    imin = imin // "*"
		}
	    impath = imdir // imin
	    filepath.files = ""
	    filepath (impath)
	    impath = filepath.files
	    if (!access (impath)) {
		print ("TRSFILES: Cannot read file ",impath)
		next
		}
	    filename (impath)
	    imfile = filename.filename
	    lfile = strlen (imfile)
	    if (lfile > maxlfile)
		maxlfile = lfile
	    if (impath != lastpath) {
		if (cp) {
		    if (ad) {
			imfile = ddir // "." // imfile
			}
		    if (access (imfile))
			delete (imfile)
		    copy (impath, imfile)
		    print (imfile, >>tempout)
		    if (db)
			print ("TRSFILES: Copying file ",impath," to ",imfile)
		    else if (vb)
			print (imfile)
		    }
		else {
		    print (impath, >>tempout)
		    if (db)
			print ("TRSFILES: Reading file ",impath)
		    else if (vb)
			print (impath)
		    }
		}
	    lastpath = impath
	    impath = impath // "[0]"
	    imgetp (impath, "i_title")
	    lobj = strlen (imgetp.value)
	    if (lobj > maxlobj)
		maxlobj = lobj
	    }
	}
    else
	tempout = tempin
    return
end

# Feb 15 2008	New task to parse input file lists
# Apr  4 2008	Add addate parameter so prepending observation date is optional
# Apr 10 2008	Fix error messages
